Changelog
=========

Version 1.3
-----------
- output warning at installation if extension module could not be compiled

Version 1.2
-----------
- add numpy to install_requires and fix problem with newer f2py versions

Version 1.1
-----------
- added Python 3 support
- allow objective function to raise exception where undefined

Version 1.0
-----------
Initial version
